/*
 * Copyright (c) 2022-present Charles7c Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.zayac.admin.agent.model.resp;

import java.io.Serial;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.math.BigDecimal;

import lombok.Data;

import io.swagger.v3.oas.annotations.media.Schema;

import top.continew.starter.extension.crud.model.resp.BaseResp;

/**
 * 代理线财务报信息
 *
 * @author zayac
 * @since 2024/06/04 17:14
 */
@Data
@Schema(description = "代理线财务报信息")
public class FinanceResp extends BaseResp {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 会员ID
     */
    @Schema(description = "会员ID")
    private Long memberId;

    /**
     * 代理名称
     */
    @Schema(description = "代理名称")
    private String agentName;

    /**
     * 邀请码
     */
    @Schema(description = "邀请码")
    private String inviteCode;

    /**
     * 顶级代理名称
     */
    @Schema(description = "顶级代理名称")
    private String topName;

    /**
     * 分类ID
     */
    @Schema(description = "分类ID")
    private Integer category;

    /**
     * 分类名称
     */
    @Schema(description = "分类名称")
    private String categoryName;

    /**
     * 佣金日期
     */
    @Schema(description = "佣金日期")
    private LocalDate commissionDate;

    /**
     * 活跃状态
     */
    @Schema(description = "活跃状态")
    private Integer active;

    /**
     * 下属用户数量
     */
    @Schema(description = "下属用户数量")
    private Integer subordinateUserCount;

    /**
     * 存款金额
     */
    @Schema(description = "存款金额")
    private BigDecimal deposit;

    /**
     * 取款金额
     */
    @Schema(description = "取款金额")
    private BigDecimal draw;

    /**
     * 利润
     */
    @Schema(description = "利润")
    private BigDecimal profit;

    /**
     * 第三方支出
     */
    @Schema(description = "第三方支出")
    private BigDecimal thirdPartySpend;

    /**
     * 促销金额
     */
    @Schema(description = "促销金额")
    private BigDecimal promo;

    /**
     * 回扣金额
     */
    @Schema(description = "回扣金额")
    private BigDecimal rebate;

    /**
     * 净利润
     */
    @Schema(description = "净利润")
    private BigDecimal netProfit;

    /**
     * 风险调整金额
     */
    @Schema(description = "风险调整金额")
    private BigDecimal riskAdjust;

    /**
     * 调整后利润
     */
    @Schema(description = "调整后利润")
    private String czProfit;

    /**
     * 费率
     */
    @Schema(description = "费率")
    private String rate;

    /**
     * 上一次余额
     */
    @Schema(description = "上一次余额")
    private BigDecimal lastBalance;

    /**
     * 修正值
     */
    @Schema(description = "修正值")
    private BigDecimal correction;

    /**
     * 佣金
     */
    @Schema(description = "佣金")
    private BigDecimal commission;

    /**
     * 余额
     */
    @Schema(description = "余额")
    private BigDecimal balance;

    /**
     * 备注
     */
    @Schema(description = "备注")
    private String remark;

    /**
     * 代理备注
     */
    @Schema(description = "代理备注")
    private String agentRemark;

    /**
     * 管理员名称
     */
    @Schema(description = "管理员名称")
    private String adminName;

    /**
     * 佣金状态
     */
    @Schema(description = "佣金状态")
    private Integer commissionStatus;

    /**
     * 平台详情
     */
    @Schema(description = "平台详情")
    private String plateDetail;

    /**
     * 发布日期
     */
    @Schema(description = "发布日期")
    private LocalDateTime releaseAt;

    /**
     * 团队名称
     */
    @Schema(description = "团队名称")
    private String teamName;

    /**
     * 发送备注
     */
    @Schema(description = "发送备注")
    private String sendRemark;

    /**
     * 代理状态
     */
    @Schema(description = "代理状态")
    private Integer agentStatus;

    /**
     * 二级线路
     */
    @Schema(description = "二级线路")
    private Integer secondaryLine;

    /**
     * 是否为队长
     */
    @Schema(description = "是否为队长")
    private Boolean isCaptain;

    /**
     * 名称
     */
    @Schema(description = "名称")
    private String name;

    /**
     * 存款次数
     */
    @Schema(description = "存款次数")
    private Integer countDeposit;

    /**
     * 取款次数
     */
    @Schema(description = "取款次数")
    private Integer countDraw;

    /**
     * 投注次数
     */
    @Schema(description = "投注次数")
    private Integer countBets;

    /**
     * VIP特殊佣金
     */
    @Schema(description = "VIP特殊佣金")
    private String vipSpecialCommission;

    /**
     * 新的活跃状态
     */
    @Schema(description = "新的活跃状态")
    private Integer newActive;

    /**
     * 修正后的净利润
     */
    @Schema(description = "修正后的净利润")
    private String repairNetProfit;

    /**
     * 显示的佣金率
     */
    @Schema(description = "显示的佣金率")
    private Integer showCommissionRate;

    /**
     * 有效的新用户
     */
    @Schema(description = "有效的新用户")
    private Integer effectiveNew;

    /**
     * 修正值
     */
    @Schema(description = "修正值")
    private String repCorrection;

    /**
     * 手续费
     */
    @Schema(description = "手续费")
    private BigDecimal handlingFee;

    /**
     * 合作利润
     */
    @Schema(description = "合作利润")
    private Integer partnershipProfit;

    /**
     * 投注金额
     */
    @Schema(description = "投注金额")
    private BigDecimal bets;

    /**
     * 彩票投注金额
     */
    @Schema(description = "彩票投注金额")
    private BigDecimal lotteryBet;

    /**
     * 成本金额
     */
    @Schema(description = "成本金额")
    private BigDecimal costMoney;

    /**
     * 成本率
     */
    @Schema(description = "成本率")
    private BigDecimal costRate;

    /**
     * 回扣率
     */
    @Schema(description = "回扣率")
    private BigDecimal rebateRate;

    /**
     * 彩票佣金
     */
    @Schema(description = "彩票佣金")
    private BigDecimal lotteryCommission;

    /**
     * 负利润率
     */
    @Schema(description = "负利润率")
    private BigDecimal negativeProfitRate;

    /**
     * 负利润佣金
     */
    @Schema(description = "负利润佣金")
    private BigDecimal negativeProfitCommission;

    /**
     * 彩票利润
     */
    @Schema(description = "彩票利润")
    private BigDecimal lotteryProfit;

    /**
     * 修改人
     */
    @Schema(description = "修改人")
    private Long updateUser;

    /**
     * 修改时间
     */
    @Schema(description = "修改时间")
    private LocalDateTime updateTime;
}