/*
 * Copyright (c) 2022-present Charles7c Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.zayac.admin.service;

import com.zayac.admin.constant.ApiPathConstants;
import com.zayac.admin.req.team.TeamFinanceReq;
import com.zayac.admin.resp.team.TeamAccountFinance;
import com.zayac.admin.resp.team.TeamFinancePagination;
import com.zayac.admin.system.model.resp.AccountResp;
import lombok.RequiredArgsConstructor;
import org.springframework.core.ParameterizedTypeReference;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.concurrent.CompletableFuture;

@Service
@RequiredArgsConstructor
public class CompletableFutureFinanceService {
    private final CompletableFutureWebClientService completableFutureWebClientService;

    public CompletableFuture<TeamFinancePagination<List<TeamAccountFinance>>> getTeamFinance(AccountResp account,
                                                                                             TeamFinanceReq teamFinanceReq) {
        //设置一个超大的分页参数 确保一次查询到所有的代理线
        if (teamFinanceReq.getPageSize() == 0) {
            teamFinanceReq.setPageSize(100);
        }
        if (teamFinanceReq.getPageNum() == 0) {
            teamFinanceReq.setPageNum(1);
        }

        return completableFutureWebClientService
            .fetchDataForAccount(account, ApiPathConstants.TEAM_FINANCE_EXCEL, teamFinanceReq, new ParameterizedTypeReference<>() {
            });
    }
}
