/*
 * Copyright (c) 2022-present Charles7c Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.zayac.admin.utils;

import java.util.List;

public class TableFormatter {

    private static final int COLUMN_SPACING = 4; // 定义列之间的间距

    public static String formatMarkdownTable(List<String[]> rows) {
        int[] colWidths = calculateColumnWidths(rows);
        StringBuilder table = new StringBuilder("```\n");
        for (String[] row : rows) {
            table.append(formatRow(row, colWidths)).append("\n");
        }
        table.append("```");
        return table.toString();
    }

    public static String formatTable(List<String[]> rows) {
        int[] colWidths = calculateColumnWidths(rows);
        StringBuilder table = new StringBuilder();
        for (String[] row : rows) {
            table.append(formatRow(row, colWidths)).append("\n");
        }
        return table.toString();
    }

    public static String formatTableAsHtml(List<String[]> rows) {
        int[] colWidths = calculateColumnWidths(rows);
        StringBuilder table = new StringBuilder("<pre>\n");
        rows.add(0, new String[] {"平台", "注册", "新增", "转化率"});
        rows.add(1, new String[] {"----", "----", "----", "----"});
        for (String[] row : rows) {
            table.append(formatRow(row, colWidths)).append("\n");
        }
        table.append("</pre>");
        return table.toString();
    }

    private static int[] calculateColumnWidths(List<String[]> rows) {
        int[] colWidths = new int[rows.get(0).length];
        for (String[] row : rows) {
            for (int i = 0; i < row.length; i++) {
                colWidths[i] = Math.max(colWidths[i], getStringWidth(row[i]));
            }
        }
        return colWidths;
    }

    private static String formatRow(String[] row, int[] colWidths) {
        StringBuilder formattedRow = new StringBuilder();
        for (int i = 0; i < row.length; i++) {
            formattedRow.append(padRight(row[i], colWidths[i])).append(" ".repeat(COLUMN_SPACING));
        }
        return formattedRow.toString().trim();
    }

    private static int getStringWidth(String s) {
        return s.codePoints().map(ch -> ch > 0xFF ? 2 : 1).sum();
    }

    private static String padRight(String s, int n) {
        int width = getStringWidth(s);
        int padding = n - width;
        return s + " ".repeat(Math.max(0, padding));
    }
}
