/*
 * Copyright (c) 2022-present Charles7c Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.zayac.admin.common.config.mybatis;

import cn.dev33.satoken.exception.NotWebContextException;
import cn.hutool.core.convert.Convert;
import com.zayac.admin.common.model.dto.LoginUser;
import com.zayac.admin.common.util.helper.LoginHelper;
import top.continew.starter.data.mybatis.plus.datapermission.DataPermissionCurrentUser;
import top.continew.starter.data.mybatis.plus.datapermission.DataPermissionFilter;
import top.continew.starter.data.mybatis.plus.datapermission.DataScope;

import java.util.Set;
import java.util.stream.Collectors;

public class DataPermissionFilterImpl implements DataPermissionFilter {

    @Override
    public boolean isFilter() {
        try {
            LoginUser loginUser = LoginHelper.getLoginUser();
            return !loginUser.isAdmin();
        } catch (NotWebContextException e) {
            return false; // 根据具体情况调整此返回值
        }
    }

    @Override
    public DataPermissionCurrentUser getCurrentUser() {
        try {
            LoginUser loginUser = LoginHelper.getLoginUser();
            return convertToDataPermissionCurrentUser(loginUser);
        } catch (NotWebContextException e) {
            // 提供定时任务的默认用户数据权限配置
            return getDefaultUserDataPermission();
        }
    }

    private DataPermissionCurrentUser convertToDataPermissionCurrentUser(LoginUser loginUser) {
        DataPermissionCurrentUser currentUser = new DataPermissionCurrentUser();
        currentUser.setUserId(Convert.toStr(loginUser.getId()));
        currentUser.setDeptId(Convert.toStr(loginUser.getDeptId()));
        currentUser.setRoles(loginUser.getRoles()
            .stream()
            .map(r -> new DataPermissionCurrentUser.CurrentUserRole(Convert.toStr(r.getId()), DataScope.valueOf(r
                .getDataScope()
                .name())))
            .collect(Collectors.toSet()));
        return currentUser;
    }

    private DataPermissionCurrentUser getDefaultUserDataPermission() {
        // 创建一个具有特定角色和数据权限的默认用户
        DataPermissionCurrentUser currentUser = new DataPermissionCurrentUser();
        currentUser.setUserId("1"); // 代表系统用户
        currentUser.setDeptId("1"); // 可以设定一个默认部门
        currentUser.setRoles(Set.of(new DataPermissionCurrentUser.CurrentUserRole("1", DataScope.CUSTOM)));
        return currentUser;
    }
}