/*
 * Copyright (c) 2022-present Charles7c Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.zayac.admin.system.model.query;

import java.io.Serial;
import java.io.Serializable;

import lombok.Data;

import io.swagger.v3.oas.annotations.media.Schema;

import top.continew.starter.data.core.annotation.Query;
import top.continew.starter.data.core.enums.QueryType;

/**
 * 账号查询条件
 *
 * @author zayac
 * @since 2024/05/10 20:44
 */
@Data
@Schema(description = "账号查询条件")
public class AccountQuery implements Serializable {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 账号昵称
     */
    @Schema(description = "账号昵称")
    @Query(type = QueryType.EQ)
    private String nickname;

    /**
     * 账号
     */
    @Schema(description = "账号")
    @Query(type = QueryType.EQ)
    private String username;

    /**
     * 所属平台
     */
    @Schema(description = "账号类型(0:开云,1:华体会,2:九游,3:爱游戏)")
    @Query(type = QueryType.EQ)
    private Long platformId;

    /**
     * 所属账号
     */
    @Schema(description = "所属用户")
    @Query(type = QueryType.EQ)
    private Long userId;

    /**
     * 状态（1：启用；2：禁用)
     */
    @Schema(description = "状态（1：启用；2：禁用)")
    @Query(type = QueryType.EQ)
    private Integer status;
}