/*
 * Copyright (c) 2022-present Charles7c Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.zayac.admin.system.model.req;

import java.io.Serial;

import com.zayac.admin.common.enums.DisEnableStatusEnum;
import jakarta.validation.constraints.*;

import lombok.Data;

import io.swagger.v3.oas.annotations.media.Schema;

import org.hibernate.validator.constraints.Length;

import top.continew.starter.extension.crud.model.req.BaseReq;

/**
 * 创建或修改账号信息
 *
 * @author zayac
 * @since 2024/05/10 20:44
 */
@Data
@Schema(description = "创建或修改账号信息")
public class AccountReq extends BaseReq {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 账号昵称
     */
    @Schema(description = "账号昵称")
    @Length(max = 60, message = "账号昵称长度不能超过 {max} 个字符")
    private String nickname;

    /**
     * 账号
     */
    @Schema(description = "账号")
    @NotBlank(message = "账号不能为空")
    @Length(max = 20, message = "账号长度不能超过 {max} 个字符")
    private String username;

    /**
     * 密码
     */
    @Schema(description = "密码")
    @NotBlank(message = "密码不能为空")
    @Length(max = 64, message = "密码长度不能超过 {max} 个字符")
    private String password;

    /**
     * 状态（1：启用；2：禁用)
     */
    @Schema(description = "状态（1：启用；2：禁用）", type = "Integer", allowableValues = {"1", "2"}, example = "1")
    @NotNull(message = "状态（1：启用；2：禁用)不能为空")
    private DisEnableStatusEnum status;

    /**
     * 所属用户ID
     */
    @Schema(description = "所属用户", example = "123456789")
    private Long userId;

    /**
     * 所属平台ID
     */
    @Schema(description = "所属平台ID", example = "123456789")
    private Long platformId;

    /**
     * 是否团团队账号
     */
    @Schema(description = "是否团团队账号", example = "false")
    private Boolean isTeam;

}