/*
 * Copyright (c) 2022-present Charles7c Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.zayac.admin.system.model.resp;

import java.io.Serial;

import cn.crane4j.annotation.AssembleMethod;
import cn.crane4j.annotation.ContainerMethod;
import cn.crane4j.annotation.Mapping;
import com.zayac.admin.common.enums.DisEnableStatusEnum;
import com.zayac.admin.system.service.PlatformService;
import com.zayac.admin.system.service.UserService;
import lombok.Data;

import io.swagger.v3.oas.annotations.media.Schema;

import top.continew.starter.extension.crud.model.resp.BaseResp;

/**
 * 账号信息
 *
 * @author zayac
 * @since 2024/05/10 20:44
 */
@Data
@Schema(description = "账号信息")
public class AccountResp extends BaseResp {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 账号昵称
     */
    @Schema(description = "账号昵称", example = "ky1线")
    private String nickname;

    /**
     * 账号
     */
    @Schema(description = "账号", example = "ky3tg107001")
    private String username;

    /**
     * 密码
     */
    @Schema(description = "密码", example = "tg666888")
    //    @JsonMask(MaskType.PASSWORD)
    private String password;

    /**
     * 平台名称
     */
    @Schema(description = "平台名称", example = "开云")
    private String platformName;

    /**
     * 平台名称
     */
    @Schema(description = "平台地址", example = "https://www.nvdf9.com:8003")
    private String platformUrl;

    /**
     * 平台ID
     */
    @Schema(description = "平台ID")
    @AssembleMethod(targetType = PlatformService.class, method = @ContainerMethod(bindMethod = "get", resultType = PlatformResp.class), props = {
        @Mapping(src = "url", ref = "platformUrl"), @Mapping(src = "name", ref = "platformName")})
    private Long platformId;

    /**
     * headers
     */
    @Schema(description = "headers", type = "JSON")
    private String headers;

    /**
     * 状态（1：启用；2：禁用)
     */
    @Schema(description = "状态（1：启用；2：禁用）", type = "Integer", allowableValues = {"1", "2"}, example = "1")
    private DisEnableStatusEnum status;

    /**
     * 用户ID
     */
    @Schema(description = "用户ID")
    @AssembleMethod(targetType = UserService.class, method = @ContainerMethod(bindMethod = "get", resultType = UserResp.class), props = @Mapping(src = "username", ref = "ownerName"))
    private Long userId;

    /**
     * 所属用户
     */
    @Schema(description = "所属用户", example = "张三")
    private String ownerName;

    /**
     * 是否为团队账号
     */
    @Schema(description = "是否为团队账号", example = "false")
    private Boolean isTeam;

}