/*
 * Copyright (c) 2022-present Charles7c Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.zayac.admin.system.model.resp;

import java.io.Serial;

import com.zayac.admin.common.enums.DisEnableStatusEnum;
import lombok.Data;

import io.swagger.v3.oas.annotations.media.Schema;

import com.alibaba.excel.annotation.ExcelIgnoreUnannotated;
import com.alibaba.excel.annotation.ExcelProperty;

import top.continew.starter.extension.crud.model.resp.BaseDetailResp;

/**
 * 平台详情信息
 *
 * @author zayac
 * @since 2024/05/14 12:28
 */
@Data
@ExcelIgnoreUnannotated
@Schema(description = "平台详情信息")
public class PlatformDetailResp extends BaseDetailResp {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 平台代码
     */
    @Schema(description = "平台代码")
    @ExcelProperty(value = "平台代码")
    private Integer code;

    /**
     * 平台名称
     */
    @Schema(description = "平台名称")
    @ExcelProperty(value = "平台名称")
    private String name;

    /**
     * 平台名称
     */
    @Schema(description = "平台别称")
    @ExcelProperty(value = "平台别称")
    private String nickname;

    /**
     * 平台地址
     */
    @Schema(description = "平台地址")
    @ExcelProperty(value = "平台地址")
    private String url;

    /**
     * 状态(1启用,2禁用)
     */
    @Schema(description = "状态（1：启用；2：禁用）", type = "Integer", allowableValues = {"1", "2"}, example = "1")
    @ExcelProperty(value = "状态(1启用,2禁用)")
    private DisEnableStatusEnum status;

    /**
     * 描述
     */
    @Schema(description = "描述")
    @ExcelProperty(value = "描述")
    private String description;
}